@@ -1061,7 +1061,11 @@ class SQLObject(object):
         if not self.sqlmeta._creating:
             self.sqlmeta.send(events.RowUpdateSignal, self, d)
         if len(d) != 1 or name not in d:
-            return self.set(**d)
+            # Already called RowUpdateSignal, don't call it again
+            # inside .set()
+            self.sqlmeta.row_update_sig_suppress = True
+            self.set(**d)
+            del self.sqlmeta.row_update_sig_suppress
         value = d[name]
         if from_python:
             dbValue = from_python(value, self._SO_validatorState)
@@ -1083,7 +1087,7 @@ class SQLObject(object):
             setattr(self, instanceName(name), value)
 
     def set(self, **kw):
-        if not self.sqlmeta._creating:
+        if not self.sqlmeta._creating and not getattr(self.sqlmeta, "row_update_sig_suppress", False):
             self.sqlmeta.send(events.RowUpdateSignal, self, kw)
         # set() is used to update multiple values at once,
         # potentially with one SQL statement if possible.
@@ -1287,9 +1291,10 @@ class SQLObject(object):
         cache.created(id, self.__class__, self)
         self._init(id)
         post_funcs = []
-        kw = dict([('class',self.__class__),('id',id)])
+        kw = dict([('class', self.__class__), ('id', id)])
         self.sqlmeta.send(events.RowCreatedSignal, kw, post_funcs)
-
+        for func in post_funcs:
+            func(self)
 
     def _SO_getID(self, obj):
         return getID(obj)
